var Lint = require("../lint");
describe("External Formatter", function () {
    var TEST_FILE = "formatters/externalFormatter.test.ts";
    var TEST_MODULE = "../../test/files/formatters/simple";
    var sourceFile;
    var formatter;
    before(function () {
        var Formatter = Lint.Test.getFormatter(TEST_MODULE);
        sourceFile = Lint.Test.getSourceFile(TEST_FILE);
        formatter = new Formatter();
    });
    it("formats failures", function () {
        var maxPosition = sourceFile.getFullWidth();
        var failures = [
            new Lint.RuleFailure(sourceFile, 0, 1, "first failure", "first-name"),
            new Lint.RuleFailure(sourceFile, 32, 36, "mid failure", "mid-name"),
            new Lint.RuleFailure(sourceFile, maxPosition - 1, maxPosition, "last failure", "last-name")
        ];
        var expectedResult = getPositionString(1, 1) + TEST_FILE + "\n" +
            getPositionString(2, 11) + TEST_FILE + "\n" +
            getPositionString(9, 2) + TEST_FILE + "\n";
        var actualResult = formatter.format(failures);
        assert.equal(actualResult, expectedResult);
    });
    it("returns undefined for unresolvable module", function () {
        assert.isUndefined(Lint.Test.getFormatter(TEST_FILE + "/__non-existent__"));
    });
    it("handles no failures", function () {
        var result = formatter.format([]);
        assert.equal(result, "");
    });
    function getPositionString(line, character) {
        return "[" + line + ", " + character + "]";
    }
});
