var Lint = require("../lint");
describe("<member-ordering>", function () {
    it("requires public variables to go before private ones", function () {
        var fileName = "rules/memberordering-private.test.ts";
        var MemberOrderingRule = Lint.Test.getRule("member-ordering");
        var actualFailures = Lint.Test.applyRuleOnFile(fileName, MemberOrderingRule, [
            true,
            "public-before-private"
        ]);
        Lint.Test.assertFailuresEqual(actualFailures, [
            Lint.Test.createFailure(fileName, [6, 5], [6, 15], "Declaration of public instance member variable not allowed " +
                "to appear after declaration of private instance member function")
        ]);
    });
    it("requires variables to go before methods", function () {
        var fileName = "rules/memberordering-method.test.ts";
        var MemberOrderingRule = Lint.Test.getRule("member-ordering");
        var actualFailures = Lint.Test.applyRuleOnFile(fileName, MemberOrderingRule, [
            true,
            "variables-before-functions"
        ]);
        Lint.Test.assertFailuresEqual(actualFailures, [
            Lint.Test.createFailure(fileName, [12, 5], [12, 15], "Declaration of public instance member variable not allowed " +
                "to appear after declaration of public instance member function"),
            Lint.Test.createFailure(fileName, [17, 5], [17, 15], "Declaration of public instance member variable not allowed " +
                "to appear after declaration of public instance member function"),
        ]);
    });
    it("requires static variables to go before instance variables", function () {
        var fileName = "rules/memberordering-static.test.ts";
        var MemberOrderingRule = Lint.Test.getRule("member-ordering");
        var actualFailures = Lint.Test.applyRuleOnFile(fileName, MemberOrderingRule, [
            true,
            "static-before-instance"
        ]);
        Lint.Test.assertFailuresEqual(actualFailures, [
            Lint.Test.createFailure(fileName, [3, 5], [3, 22], "Declaration of public static member variable not allowed " +
                "to appear after declaration of public instance member variable")
        ]);
    });
});
